# Change Log

## [v3.1.0](https://github.com/Chyroc/WechatSogou/tree/v3.1.0) (2017-07-29)
[Full Changelog](https://github.com/Chyroc/WechatSogou/compare/v3.0.0...v3.1.0)

**Closed issues:**

- 请教下 如何能获取到 关键词搜索 一天内的列表? [\#73](https://github.com/Chyroc/WechatSogou/issues/73)

**Merged pull requests:**

- Add/get hot api / gzh =\> gzh\_info [\#109](https://github.com/Chyroc/WechatSogou/pull/109) ([Chyroc](https://github.com/Chyroc))
- Change/search article type const [\#108](https://github.com/Chyroc/WechatSogou/pull/108) ([Chyroc](https://github.com/Chyroc))
- Add const class  and  add gen hot url [\#107](https://github.com/Chyroc/WechatSogou/pull/107) ([Chyroc](https://github.com/Chyroc))
- Add retry for captcha break [\#106](https://github.com/Chyroc/WechatSogou/pull/106) ([Chyroc](https://github.com/Chyroc))
- test api in real network env [\#104](https://github.com/Chyroc/WechatSogou/pull/104) ([Chyroc](https://github.com/Chyroc))
- Release/v3.0.0 [\#103](https://github.com/Chyroc/WechatSogou/pull/103) ([Chyroc](https://github.com/Chyroc))

## [v3.0.0](https://github.com/Chyroc/WechatSogou/tree/v3.0.0) (2017-07-27)
[Full Changelog](https://github.com/Chyroc/WechatSogou/compare/v2.0.5...v3.0.0)

**Closed issues:**

- 解封成功，正在为您跳转来源地址... [\#72](https://github.com/Chyroc/WechatSogou/issues/72)
- 列表页验证码有办法绕过吗？ [\#71](https://github.com/Chyroc/WechatSogou/issues/71)
- 无法正确解析wechatid [\#70](https://github.com/Chyroc/WechatSogou/issues/70)
- 貌似抓不到点赞数和阅读数 [\#65](https://github.com/Chyroc/WechatSogou/issues/65)
- badge issue [\#64](https://github.com/Chyroc/WechatSogou/issues/64)
- 目前getcomment接口已报错，显示 404了，何解？ [\#63](https://github.com/Chyroc/WechatSogou/issues/63)
- 调用方法search\_gzh\_info\(\)搜索公众号时，获取到的结果中wechatid为‘’ [\#62](https://github.com/Chyroc/WechatSogou/issues/62)
- 跳出来验证码之后输入，报错 [\#61](https://github.com/Chyroc/WechatSogou/issues/61)
- 请问logging.config.fileConfig\('logging.conf'\)出错如何解决 [\#60](https://github.com/Chyroc/WechatSogou/issues/60)
- 可否增加验证码输入错误，能再次重新输入的机制 [\#54](https://github.com/Chyroc/WechatSogou/issues/54)
- 调用get\_gzh\_message返回{"ret":0,"errmsg":""} [\#52](https://github.com/Chyroc/WechatSogou/issues/52)
- 输入验证码后报错 [\#32](https://github.com/Chyroc/WechatSogou/issues/32)
- 作者：对于本项目的类及方法命名，有什么建议？ [\#30](https://github.com/Chyroc/WechatSogou/issues/30)
- 文章列表页也可能出现验证码 [\#29](https://github.com/Chyroc/WechatSogou/issues/29)
- 功能与意见反馈，报bug可以另开issue [\#28](https://github.com/Chyroc/WechatSogou/issues/28)
- 调试几次后，开始无法爬取，是因为搜狗的反爬虫策略吗？ [\#26](https://github.com/Chyroc/WechatSogou/issues/26)
- 对时间的支持 [\#19](https://github.com/Chyroc/WechatSogou/issues/19)

**Merged pull requests:**

- add get sugg [\#102](https://github.com/Chyroc/WechatSogou/pull/102) ([Chyroc](https://github.com/Chyroc))
- Fix readme [\#101](https://github.com/Chyroc/WechatSogou/pull/101) ([Chyroc](https://github.com/Chyroc))
- modify the readme file [\#100](https://github.com/Chyroc/WechatSogou/pull/100) ([Chyroc](https://github.com/Chyroc))
- add doc for refactored api [\#99](https://github.com/Chyroc/WechatSogou/pull/99) ([Chyroc](https://github.com/Chyroc))
- refactor get info from history [\#98](https://github.com/Chyroc/WechatSogou/pull/98) ([Chyroc](https://github.com/Chyroc))
- remove unused file / fix name / add comment [\#97](https://github.com/Chyroc/WechatSogou/pull/97) ([Chyroc](https://github.com/Chyroc))
- merge 原来的api 和 重构后的api [\#96](https://github.com/Chyroc/WechatSogou/pull/96) ([Chyroc](https://github.com/Chyroc))
- Add get gzh and article by history [\#95](https://github.com/Chyroc/WechatSogou/pull/95) ([Chyroc](https://github.com/Chyroc))
- Add get gzh by id or name [\#94](https://github.com/Chyroc/WechatSogou/pull/94) ([Chyroc](https://github.com/Chyroc))
- add search article api [\#93](https://github.com/Chyroc/WechatSogou/pull/93) ([Chyroc](https://github.com/Chyroc))
- add callback func [\#92](https://github.com/Chyroc/WechatSogou/pull/92) ([Chyroc](https://github.com/Chyroc))
- split test / add error html [\#91](https://github.com/Chyroc/WechatSogou/pull/91) ([Chyroc](https://github.com/Chyroc))
- Add annotation and remove all type from history page [\#89](https://github.com/Chyroc/WechatSogou/pull/89) ([Chyroc](https://github.com/Chyroc))
- Add annotation and fix [\#88](https://github.com/Chyroc/WechatSogou/pull/88) ([Chyroc](https://github.com/Chyroc))
- split test get gzh\_info and articel [\#87](https://github.com/Chyroc/WechatSogou/pull/87) ([Chyroc](https://github.com/Chyroc))
- add structuring-gzh-article-from-history [\#86](https://github.com/Chyroc/WechatSogou/pull/86) ([Chyroc](https://github.com/Chyroc))
- Structuring gzh from history [\#85](https://github.com/Chyroc/WechatSogou/pull/85) ([Chyroc](https://github.com/Chyroc))
- test struct article list [\#84](https://github.com/Chyroc/WechatSogou/pull/84) ([Chyroc](https://github.com/Chyroc))
- Structuring gzh by search [\#83](https://github.com/Chyroc/WechatSogou/pull/83) ([Chyroc](https://github.com/Chyroc))
- fix repo language [\#82](https://github.com/Chyroc/WechatSogou/pull/82) ([Chyroc](https://github.com/Chyroc))
- fix repo language [\#81](https://github.com/Chyroc/WechatSogou/pull/81) ([Chyroc](https://github.com/Chyroc))
- Search gzh article text [\#80](https://github.com/Chyroc/WechatSogou/pull/80) ([Chyroc](https://github.com/Chyroc))
- add test gen search gzh url [\#79](https://github.com/Chyroc/WechatSogou/pull/79) ([Chyroc](https://github.com/Chyroc))
- Refactor gen search url [\#78](https://github.com/Chyroc/WechatSogou/pull/78) ([Chyroc](https://github.com/Chyroc))
- release v2.0.4 -\> v2.0.5 [\#77](https://github.com/Chyroc/WechatSogou/pull/77) ([Chyroc](https://github.com/Chyroc))

## [v2.0.5](https://github.com/Chyroc/WechatSogou/tree/v2.0.5) (2017-07-22)
[Full Changelog](https://github.com/Chyroc/WechatSogou/compare/v2.0.4...v2.0.5)

**Merged pull requests:**

- fix setup python version name [\#76](https://github.com/Chyroc/WechatSogou/pull/76) ([Chyroc](https://github.com/Chyroc))
- Release/v2.0.4 [\#75](https://github.com/Chyroc/WechatSogou/pull/75) ([Chyroc](https://github.com/Chyroc))

## [v2.0.4](https://github.com/Chyroc/WechatSogou/tree/v2.0.4) (2017-07-22)
[Full Changelog](https://github.com/Chyroc/WechatSogou/compare/v2.0.3...v2.0.4)

**Closed issues:**

- pip 安装 No module named requests 什么情况 [\#59](https://github.com/Chyroc/WechatSogou/issues/59)
- 微信搜索公众号结果模版改变了 [\#51](https://github.com/Chyroc/WechatSogou/issues/51)
-  ImportError: cannot import name config [\#40](https://github.com/Chyroc/WechatSogou/issues/40)

**Merged pull requests:**

- Makefile tox [\#74](https://github.com/Chyroc/WechatSogou/pull/74) ([Chyroc](https://github.com/Chyroc))
- fix typo [\#69](https://github.com/Chyroc/WechatSogou/pull/69) ([Chyroc](https://github.com/Chyroc))
- Add tools test [\#68](https://github.com/Chyroc/WechatSogou/pull/68) ([Chyroc](https://github.com/Chyroc))
- fix import and mv tools function [\#67](https://github.com/Chyroc/WechatSogou/pull/67) ([Chyroc](https://github.com/Chyroc))
- update package [\#66](https://github.com/Chyroc/WechatSogou/pull/66) ([Chyroc](https://github.com/Chyroc))
- add ci icon [\#58](https://github.com/Chyroc/WechatSogou/pull/58) ([Chyroc](https://github.com/Chyroc))
- Add travis ci [\#57](https://github.com/Chyroc/WechatSogou/pull/57) ([Chyroc](https://github.com/Chyroc))
- release v2.0.3 [\#56](https://github.com/Chyroc/WechatSogou/pull/56) ([Chyroc](https://github.com/Chyroc))

## [v2.0.3](https://github.com/Chyroc/WechatSogou/tree/v2.0.3) (2016-12-18)
**Closed issues:**

- 引入模块的时候报错 [\#33](https://github.com/Chyroc/WechatSogou/issues/33)
- 导入文件后有bug [\#31](https://github.com/Chyroc/WechatSogou/issues/31)
- 请问如何设置代理 [\#27](https://github.com/Chyroc/WechatSogou/issues/27)
- 请问最近搜狗返回的Html内容是改了吗？最近抓内容出错。 [\#25](https://github.com/Chyroc/WechatSogou/issues/25)
- 结果模版更新了 [\#24](https://github.com/Chyroc/WechatSogou/issues/24)
- 文章标题带引号（"，&quot）的情况解析报错 [\#23](https://github.com/Chyroc/WechatSogou/issues/23)
- 请问，我运行test.py时为何没报错却没得到任何结果？ [\#21](https://github.com/Chyroc/WechatSogou/issues/21)
- 如何获得公众号的id和名称？ [\#20](https://github.com/Chyroc/WechatSogou/issues/20)
- search\_gzh\_info无法取得内容 [\#18](https://github.com/Chyroc/WechatSogou/issues/18)
- 原始文章url [\#17](https://github.com/Chyroc/WechatSogou/issues/17)
- 请问在Linux下可以使用吗？我运行了一下出现如下问题，还望指教 [\#16](https://github.com/Chyroc/WechatSogou/issues/16)
- log怎么使用？ [\#15](https://github.com/Chyroc/WechatSogou/issues/15)
- 抓取数据有时成功，有时失败 [\#14](https://github.com/Chyroc/WechatSogou/issues/14)
- 验证码打开失败问题原因是： [\#13](https://github.com/Chyroc/WechatSogou/issues/13)
- 验证码输入后失败 [\#12](https://github.com/Chyroc/WechatSogou/issues/12)
- 获得的文章链接，如果打开需要验证码输入才跳转 [\#11](https://github.com/Chyroc/WechatSogou/issues/11)
- 获取文章只能10篇？ [\#10](https://github.com/Chyroc/WechatSogou/issues/10)
- 搜狗平台问题 [\#9](https://github.com/Chyroc/WechatSogou/issues/9)
- deal\_article\_comment\(text=text\)并不能获得用户的评论内容 [\#8](https://github.com/Chyroc/WechatSogou/issues/8)
- py2.7 什么时候支持？ [\#7](https://github.com/Chyroc/WechatSogou/issues/7)
- PIL is not support Python3 [\#6](https://github.com/Chyroc/WechatSogou/issues/6)
- 演示代码wechats.get\_gzh\_article\_by\_url\_dict\(wechat\_info\['url'\]\)提示list index out of range [\#5](https://github.com/Chyroc/WechatSogou/issues/5)
- 如何使用代理 [\#2](https://github.com/Chyroc/WechatSogou/issues/2)
- 使用的是 python3 吗？ [\#1](https://github.com/Chyroc/WechatSogou/issues/1)

**Merged pull requests:**

- fix for ci [\#50](https://github.com/Chyroc/WechatSogou/pull/50) ([Chyroc](https://github.com/Chyroc))
- add readme.rst [\#48](https://github.com/Chyroc/WechatSogou/pull/48) ([Chyroc](https://github.com/Chyroc))
- 添加安装说明 [\#47](https://github.com/Chyroc/WechatSogou/pull/47) ([Chyroc](https://github.com/Chyroc))
- upload to pypi [\#46](https://github.com/Chyroc/WechatSogou/pull/46) ([Chyroc](https://github.com/Chyroc))
- add [\#45](https://github.com/Chyroc/WechatSogou/pull/45) ([Chyroc](https://github.com/Chyroc))
- Add/api test [\#44](https://github.com/Chyroc/WechatSogou/pull/44) ([Chyroc](https://github.com/Chyroc))
- Fix/re ocr for  get gzh article by url text [\#43](https://github.com/Chyroc/WechatSogou/pull/43) ([Chyroc](https://github.com/Chyroc))
- 修复首页热门获取单页 [\#42](https://github.com/Chyroc/WechatSogou/pull/42) ([Chyroc](https://github.com/Chyroc))
- Fix/search article info [\#41](https://github.com/Chyroc/WechatSogou/pull/41) ([Chyroc](https://github.com/Chyroc))
- Add/readme zanshu [\#39](https://github.com/Chyroc/WechatSogou/pull/39) ([Chyroc](https://github.com/Chyroc))
- Fix/test ruokuai [\#38](https://github.com/Chyroc/WechatSogou/pull/38) ([Chyroc](https://github.com/Chyroc))
- Feature/test ruokuai [\#37](https://github.com/Chyroc/WechatSogou/pull/37) ([Chyroc](https://github.com/Chyroc))
- Feature/update version [\#35](https://github.com/Chyroc/WechatSogou/pull/35) ([Chyroc](https://github.com/Chyroc))
- add requirements.txt [\#34](https://github.com/Chyroc/WechatSogou/pull/34) ([Chyroc](https://github.com/Chyroc))



\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*